# This is free and unencumbered software released into the public domain.

"""Haltia.AI Software Development Kit (SDK) for Python"""

import sys

assert sys.version_info >= (3, 9), "Haltia.AI Software Development Kit (SDK) for Python requires Python 3.9+"

__all__ = []
